==> curia-0.0.69-py2.py3-none-any.whl: curia/api/docs/ModelJob.md <==
# ModelJob

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**summary_data** | **object** |  | [optional] 
**schema** | **object** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**project** | [**Project**](Project.md) |  | [optional] 
**model** | [**Model**](Model.md) |  | [optional] 
**cohort** | [**Cohort**](Cohort.md) |  | [optional] 
**dataset** | [**Dataset**](Dataset.md) |  | [optional] 
**events** | [**list[ModelJobEvent]**](ModelJobEvent.md) |  | [optional] 
**endpoints** | [**list[ModelEndpoint]**](ModelEndpoint.md) |  | [optional] 
**outputs** | [**list[ModelJobOutput]**](ModelJobOutput.md) |  | [optional] 
**model_job_output_features** | [**list[ModelJobOutputFeature]**](ModelJobOutputFeature.md) |  | [optional] 
**model_job_statuses** | [**list[ModelJobStatus]**](ModelJobStatus.md) |  | [optional] 
**feature_sub_categories** | [**list[FeatureSubCategory]**](FeatureSubCategory.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> curia-2.1.0-py2.py3-none-any.whl: curia/api/docs/ModelJob.md <==
# ModelJob

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**type** | **str** |  | 
**outcome_type** | **str** |  | [optional] 
**config** | [**ModelJobConfig**](ModelJobConfig.md) |  | [optional] 
**execution_id** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**project_id** | **str** |  | 
**model_id** | **str** |  | 
**model_batch_job_id** | **str** |  | [optional] 
**model_batch_job** | [**ModelBatchJob**](ModelBatchJob.md) |  | [optional] 
**cohort_id** | **str** |  | [optional] 
**dataset_id** | **str** |  | [optional] 
**project** | [**Project**](Project.md) |  | [optional] 
**model** | [**Model**](Model.md) |  | [optional] 
**cohort** | [**Cohort**](Cohort.md) |  | [optional] 
**model_population_id** | **str** |  | [optional] 
**model_population** | [**ModelPopulation**](ModelPopulation.md) |  | [optional] 
**dataset** | [**Dataset**](Dataset.md) |  | [optional] 
**events** | [**list[ModelJobEvent]**](ModelJobEvent.md) |  | [optional] 
**outputs** | [**list[ModelJobOutput]**](ModelJobOutput.md) |  | [optional] 
**model_job_statuses** | [**list[ModelJobStatus]**](ModelJobStatus.md) |  | [optional] 
**feature_sub_categories** | [**list[FeatureSubCategory]**](FeatureSubCategory.md) |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**created_by** | **str** |  | [optional] 
**started_at** | **datetime** |  | [optional] 
**ended_at** | **datetime** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
